:maintainers:
  `andrewtarzia <https://github.com/andrewtarzia/>`_

Overview
========

``htse`` is a Python library for evaluating molecular exclusion in a 
high-throughput way.

Installation
============

To get ``htse``, you can install it with pip:

.. code-block:: bash

  pip install htse


Warning:

  Very much underdevelopment. There are no tests currently!

Developer Setup
---------------

1. Install `just`_.
2. Install `uv`_.
3. In the source directory, run:

.. code-block:: bash

  just setup

3. Run code checks:

.. code-block:: bash

  just check


.. _`just`: https://github.com/casey/just
.. _`uv`: https://docs.astral.sh

How To Cite
===========

If you use ``htse`` please cite

  https://github.com/andrewtarzia/HTSExclusion


Publications
============
